Running the test suite
======================

In order to run the test suite for ``django-envie`` run the following command from the
cli:

    .. code-block:: none

        $ python setup.py test

You should see the tests complete without errors!